pub struct Span {
pub row: usize,
pub end_row: usize,
pub col: usize,
pub end_col: usize,
}Fields
row: usizeend_row: usizecol: usizeend_col: usizeImplementations
Sourceimpl Span
impl Span
pub fn new(row: usize, end_row: usize, col: usize, end_col: usize) -> Self
Sourcepub fn kind(&self) -> SelectionKind
pub fn kind(&self) -> SelectionKind
Returns the SelectionKind:
end_row == NO_ENDbutend_col != NO_END→Rowsend_col == NO_ENDbutend_row != NO_END→Cols- anything else →
Cells
Sourcepub fn rows_start_end(&self, grid: &TableGrid) -> (usize, usize)
pub fn rows_start_end(&self, grid: &TableGrid) -> (usize, usize)
Inclusive start index and end index of the span
Sourcepub fn cols_start_end(&self, grid: &TableGrid) -> (usize, usize)
pub fn cols_start_end(&self, grid: &TableGrid) -> (usize, usize)
Inclusive start index and end index of the span