pub struct Table { /* private fields */ }Implementations
Sourceimpl Table
impl Table
Sourcepub fn add_cols(
&mut self,
kwargs: Option<AddArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn add_cols( &mut self, kwargs: Option<AddArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Add new cols with the provided item ids to the Table.
Sourcepub fn add_num_cols(
&mut self,
kwargs: Option<AddNumArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn add_num_cols( &mut self, kwargs: Option<AddNumArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Add a number of new cols with auto-generated item ids to the Table.
Sourceimpl Table
impl Table
Sourcepub fn add_rows(
&mut self,
kwargs: Option<AddArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn add_rows( &mut self, kwargs: Option<AddArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Add new rows with the provided item ids to the Table.
Sourcepub fn add_num_rows(
&mut self,
kwargs: Option<AddNumArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn add_num_rows( &mut self, kwargs: Option<AddNumArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Add a number of new rows with auto-generated item ids to the Table.
Sourceimpl Table
impl Table
pub fn borders( &mut self, kwargs: Option<BordersArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn borders_i( &mut self, kwargs: Option<BordersArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn borders_h( &mut self, kwargs: Option<BordersArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_borders( &mut self, kwargs: Option<SetBordersArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_borders_i( &mut self, kwargs: Option<SetBordersArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_borders_h( &mut self, kwargs: Option<SetBordersArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn align( &mut self, kwargs: Option<CellAlignArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn align_i( &mut self, kwargs: Option<CellAlignArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn align_h( &mut self, kwargs: Option<CellAlignArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn checkbox( &mut self, kwargs: Option<CheckboxArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn checkbox_i( &mut self, kwargs: Option<CheckboxArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn checkbox_h( &mut self, kwargs: Option<CheckboxArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_checkbox( &mut self, kwargs: Option<SetCheckboxArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_checkbox_i( &mut self, kwargs: Option<SetCheckboxArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_checkbox_h( &mut self, kwargs: Option<SetCheckboxArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn data_format( &mut self, kwargs: Option<DataFormatArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn data_format_i( &mut self, kwargs: Option<DataFormatArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn data_format_h( &mut self, kwargs: Option<DataFormatArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
Sourcepub fn get_data_iids<'a>(
&'a self,
kwargs: Option<GetDataIidsArgs>,
) -> Result<Vec<(String, Vec<(String, &'a Val)>)>, String>
pub fn get_data_iids<'a>( &'a self, kwargs: Option<GetDataIidsArgs>, ) -> Result<Vec<(String, Vec<(String, &'a Val)>)>, String>
Gets row data using an array of row ids or positions.
Sourcepub fn get_data_yx<'a>(
&'a self,
kwargs: Option<GetDataYxArgs>,
) -> Result<Vec<(CellKey, &'a Val)>, String>
pub fn get_data_yx<'a>( &'a self, kwargs: Option<GetDataYxArgs>, ) -> Result<Vec<(CellKey, &'a Val)>, String>
Gets table cell data using cell coordinates.
Sourcepub fn get_data_span<'a>(
&'a self,
kwargs: Option<GetDataSpanArgs>,
) -> Result<Vec<Vec<&'a Val>>, String>
pub fn get_data_span<'a>( &'a self, kwargs: Option<GetDataSpanArgs>, ) -> Result<Vec<Vec<&'a Val>>, String>
Gets data as a 2d array using a key.
Sourceimpl Table
impl Table
Sourcepub fn get_data_iids_cloned(
&self,
kwargs: Option<GetDataIidsArgs>,
) -> Result<Vec<(String, Vec<(String, Val)>)>, String>
pub fn get_data_iids_cloned( &self, kwargs: Option<GetDataIidsArgs>, ) -> Result<Vec<(String, Vec<(String, Val)>)>, String>
Gets row data using an array of row ids or positions.
Sourcepub fn get_data_yx_cloned(
&self,
kwargs: Option<GetDataYxArgs>,
) -> Result<Vec<(CellKey, Val)>, String>
pub fn get_data_yx_cloned( &self, kwargs: Option<GetDataYxArgs>, ) -> Result<Vec<(CellKey, Val)>, String>
Gets table cell data using cell coordinates.
Sourcepub fn get_data_span_cloned(
&self,
kwargs: Option<GetDataSpanArgs>,
) -> Result<Vec<Vec<Val>>, String>
pub fn get_data_span_cloned( &self, kwargs: Option<GetDataSpanArgs>, ) -> Result<Vec<Vec<Val>>, String>
Gets data as a 2d array using a key.
Sourceimpl Table
impl Table
pub fn log_grid(&self) -> Result<(), String>
pub fn log_index(&self) -> Result<(), String>
pub fn log_header(&self) -> Result<(), String>
pub fn log_selection(&self) -> Result<(), String>
pub fn log_options(&self) -> Result<(), String>
pub fn log_disp_rows(&self) -> Result<(), String>
pub fn log_canvas_rows(&self) -> Result<(), String>
pub fn log_disp_cols(&self) -> Result<(), String>
pub fn log_canvas_cols(&self) -> Result<(), String>
pub fn log_undo_stack(&self) -> Result<(), String>
pub fn debug_grid(&self) -> String
pub fn debug_index(&self) -> String
pub fn debug_header(&self) -> String
pub fn debug_selection(&self) -> String
pub fn debug_options(&self) -> String
pub fn debug_disp_rows(&self) -> String
pub fn debug_canvas_rows(&self) -> String
pub fn debug_disp_cols(&self) -> String
pub fn debug_canvas_cols(&self) -> String
pub fn debug_sizes(&self) -> String
pub fn debug_tree_summary(&self) -> String
pub fn debug_full(&self) -> String
Sourceimpl Table
impl Table
Sourcepub fn del_cols(
&mut self,
kwargs: Option<DelArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn del_cols( &mut self, kwargs: Option<DelArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Delete cols from the table using item ids.
Sourcepub fn del_cols_pos(
&mut self,
kwargs: Option<DelPosArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn del_cols_pos( &mut self, kwargs: Option<DelPosArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Delete cols from the table using data positions (indices).
Sourceimpl Table
impl Table
Sourcepub fn del_rows(
&mut self,
kwargs: Option<DelArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn del_rows( &mut self, kwargs: Option<DelArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Delete rows from the table.
Sourcepub fn del_rows_pos(
&mut self,
kwargs: Option<DelPosArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn del_rows_pos( &mut self, kwargs: Option<DelPosArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Delete rows from the table using data positions (indices).
Sourceimpl Table
impl Table
pub fn dropdown( &mut self, kwargs: Option<DropdownArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn dropdown_i( &mut self, kwargs: Option<DropdownArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn dropdown_h( &mut self, kwargs: Option<DropdownArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_dropdown( &mut self, kwargs: Option<SetDropdownArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_dropdown_i( &mut self, kwargs: Option<SetDropdownArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_dropdown_h( &mut self, kwargs: Option<SetDropdownArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn highlight( &mut self, kwargs: Option<HighlightArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn highlight_i( &mut self, kwargs: Option<HighlightArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn highlight_h( &mut self, kwargs: Option<HighlightArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
Sourcepub fn item(
&mut self,
kwargs: ItemArgs,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn item( &mut self, kwargs: ItemArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Modify a table item (row).
Sourcepub fn get_item(&mut self, iid: String) -> Result<ItemResult, String>
pub fn get_item(&mut self, iid: String) -> Result<ItemResult, String>
Get information about an item (row).
Sourceimpl Table
impl Table
pub fn move_items( &mut self, kwargs: MoveItemsArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn note( &mut self, kwargs: Option<NoteArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn note_i( &mut self, kwargs: Option<NoteArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn note_h( &mut self, kwargs: Option<NoteArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_note( &mut self, kwargs: Option<SetNoteArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_note_i( &mut self, kwargs: Option<SetNoteArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_note_h( &mut self, kwargs: Option<SetNoteArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn add_progress_bar( &mut self, kwargs: AddProgressBarArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn add_progress_bar_i( &mut self, kwargs: AddProgressBarPosArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn add_progress_bar_h( &mut self, kwargs: AddProgressBarPosArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn del_progress_bar( &mut self, kwargs: DelProgressBarArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn del_progress_bar_i( &mut self, kwargs: DelProgressBarNameArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn del_progress_bar_h( &mut self, kwargs: DelProgressBarNameArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_progress_bar( &mut self, kwargs: SetProgressBarArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_progress_bar_i( &mut self, kwargs: SetProgressBarNameArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn set_progress_bar_h( &mut self, kwargs: SetProgressBarNameArgs, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn readonly( &mut self, kwargs: Option<ReadonlyArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn readonly_i( &mut self, kwargs: Option<ReadonlyArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn readonly_h( &mut self, kwargs: Option<ReadonlyArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
Sourcepub fn selection_clear(
&mut self,
kwargs: Option<SelectionClearArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn selection_clear( &mut self, kwargs: Option<SelectionClearArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Clear all selections.
Sourcepub fn select(
&mut self,
kwargs: Option<AddSelectionArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn select( &mut self, kwargs: Option<AddSelectionArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Create a selection box using a span. Uses displayed indices.
Sourcepub fn select_rows(
&mut self,
kwargs: Option<SelectRowsColsArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn select_rows( &mut self, kwargs: Option<SelectRowsColsArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Select rows using either item ids or row numbers. Uses data indices.
Sourcepub fn select_cols(
&mut self,
kwargs: Option<SelectRowsColsArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn select_cols( &mut self, kwargs: Option<SelectRowsColsArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Select cols using either item ids or col numbers. Uses data indices.
Sourceimpl Table
impl Table
pub fn sort_rows_by_cols( &mut self, kwargs: Option<SortRowsArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn total_rows(&self) -> usize
pub fn total_cols(&self) -> usize
Sourceimpl Table
impl Table
Sourcepub fn tree_extend(
&mut self,
kwargs: Option<TreeExtendArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn tree_extend( &mut self, kwargs: Option<TreeExtendArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Extend the tree by adding new rows.
Sourceimpl Table
impl Table
Sourcepub fn tree_open(
&mut self,
kwargs: Option<TreeOpenArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn tree_open( &mut self, kwargs: Option<TreeOpenArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sets items/rows to open. If used without args then all rows are opened.
Sourcepub fn tree_close(
&mut self,
kwargs: Option<TreeOpenArgs>,
) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn tree_close( &mut self, kwargs: Option<TreeOpenArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sets items/rows to closed. If used without args then all rows are closed.
Sourceimpl Table
impl Table
pub fn undo( &mut self, kwargs: Option<UndoRedoArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn redo( &mut self, kwargs: Option<UndoRedoArgs>, ) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn get_next_redo(&self) -> Result<Option<Rc<RefCell<EventData>>>, String>
pub fn get_next_undo(&self) -> Result<Option<Rc<RefCell<EventData>>>, String>
Sourceimpl Table
impl Table
pub fn acr_validate_partial_opts( partial: &mut PartialOptions, ) -> Result<(), String>
Sourcepub fn cr_merge_opts(&mut self, partial: PartialOptions) -> Result<(), String>
pub fn cr_merge_opts(&mut self, partial: PartialOptions) -> Result<(), String>
Validates input before applying settings changes to table.