pub struct BoundedDeque<T> { /* private fields */ }Implementations
Sourceimpl<T> BoundedDeque<T>
impl<T> BoundedDeque<T>
Sourcepub fn set_maxlen(&mut self, new_maxlen: usize)
pub fn set_maxlen(&mut self, new_maxlen: usize)
Sets a new maximum length for the deque. If the new maxlen is smaller than the current length, elements are removed from the start until the length is within the new limit.
Sourcepub fn get_maxlen(&self) -> usize
pub fn get_maxlen(&self) -> usize
Returns the current maximum length of the deque.
Sourcepub fn push_back(&mut self, item: T)
pub fn push_back(&mut self, item: T)
Adds an item to the end. If the deque is at capacity, removes from the start first.
Sourcepub fn push_front(&mut self, item: T)
pub fn push_front(&mut self, item: T)
Adds an item to the start. If the deque is at capacity, removes from the end first.